[PATCH 2/4] Rename environment variables in run_gui_tests.sh.

Chris Lumens clumens at redhat.com
Fri Jul 11 15:18:25 UTC 2014


I just knocked GUI_ off the front.  The plan is with multiple variations of
this kind of test going on, I'll just set these variables once and all tests
will get them.  Thus, they're not GUI specific anymore.
---
 tests/gui/run_gui_tests.sh | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/tests/gui/run_gui_tests.sh b/tests/gui/run_gui_tests.sh
index fd82ef7..b170f4b 100755
--- a/tests/gui/run_gui_tests.sh
+++ b/tests/gui/run_gui_tests.sh
@@ -44,10 +44,10 @@ if [ ${EUID} != 0 ]; then
 fi
 
 # The livecd location can come from one of two different places:
 # (1) $GUI_TEST_LIVECD, if this script is being called from "make check"
 # (2) The command line, if this script is being called directly.
-if [[ "${GUI_TEST_LIVECD}" != "" ]]; then
-    LIVECD=${GUI_TEST_LIVECD}
+if [[ "${TEST_LIVECD}" != "" ]]; then
+    LIVECD=${TEST_LIVECD}
 elif [[ $# != 0 ]]; then
     LIVECD=$1
     shift
@@ -61,8 +61,8 @@ if [ ! -e "${LIVECD}" ]; then
     exit 2
 fi
 
-if [[ "${GUI_TEST_ANACONDA_ARGS}" != "" ]]; then
-    EXTRA="--tc=anacondaArgs:\"${GUI_TEST_ANACONDA_ARGS}\""
+if [[ "${TEST_ANACONDA_ARGS}" != "" ]]; then
+    EXTRA="--tc=anacondaArgs:\"${TEST_ANACONDA_ARGS}\""
 elif [[ $# != 0 ]]; then
     EXTRA="--tc=anacondaArgs:\"$*\""
 else
@@ -44,10 +44,10 @@ if [ ${EUID} != 0 ]; then
 
 # The livecd location can come from one of two different places:
-# (1) $GUI_TEST_LIVECD, if this script is being called from "make check"
+# (1) $TEST_LIVECD, if this script is being called from "make check"
 # (2) The command line, if this script is being called directly.
-- 
1.9.3



More information about the anaconda-patches mailing list